@@ -467,7 +467,7 @@ void AlarmCalendar::removeKAEvents(Collection::Id key, bool closing, CalEvent::T
     ResourceMap::Iterator rit = mResourceMap.find(key);
     if (rit != mResourceMap.end())
     {
-        bool empty = true;
+        KAEvent::List retained;
         KAEvent::List& events = rit.value();
         for (int i = 0, end = events.count();  i < end;  ++i)
         {
@@ -487,10 +487,12 @@ void AlarmCalendar::removeKAEvents(Collection::Id key, bool closing, CalEvent::T
                 removed = true;
             }
             else
-                empty = false;
+                retained.push_back(event);
         }
-        if (empty)
+        if (retained.empty())
             mResourceMap.erase(rit);
+        else
+            events.swap(retained);
     }
     if (removed)
     {
@@ -946,7 +948,14 @@ bool AlarmCalendar::addEvent(KAEvent& evnt, QWidget* promptParent, bool useEvent
         if (collection  &&  CollectionControlModel::isEnabled(*collection, type))
             col = *collection;
         else
+        {
             col = CollectionControlModel::destination(type, promptParent, noPrompt, cancelled);
+            if (!col.isValid())
+            {
+                const char* typeStr = (type == CalEvent::ACTIVE) ? "Active alarm" : (type == CalEvent::ARCHIVED) ? "Archived alarm" : "alarm Template";
+                qCWarning(KALARM_LOG) << "AlarmCalendar::addEvent: Error! Cannot create" << typeStr << "(No default calendar is defined)";
+            }
+        }
         if (col.isValid())
         {
             // Don't add event to mEventMap yet - its Akonadi item id is not yet known.
