@@ -156,7 +156,7 @@ bool EventListView::viewportEvent(QEvent* e)
         QHelpEvent* he = static_cast<QHelpEvent*>(e);
         QModelIndex index = indexAt(he->pos());
         QVariant value = model()->data(index, Qt::ToolTipRole);
-        if (qVariantCanConvert<QString>(value))
+        if (value.canConvert<QString>())
         {
             QString toolTip = value.toString();
             int i = toolTip.indexOf(QLatin1Char('\n'));
