@@ -1,7 +1,7 @@
 /*
  *  kamail.cpp  -  email functions
  *  Program:  kalarm
- *  Copyright © 2002-2018 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2002-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,14 +33,13 @@
 #include <mailtransport/transportmanager.h>
 #include <mailtransport/transport.h>
 #include <mailtransportakonadi/messagequeuejob.h>
-#include <KCalCore/Person>
+#include <KCalendarCore/Person>
 #include <kmime/kmime_header_parsing.h>
 #include <kmime/kmime_headers.h>
 #include <kmime/kmime_message.h>
 
 #include <KEmailAddress>
 #include <KAboutData>
-#include <KLocale>
 #include <KLocalizedString>
 #include <kfileitem.h>
 #include <KIO/StatJob>
@@ -329,7 +328,7 @@ void initHeaders(KMime::Message& message, KAMail::JobData& data)
     message.setHeader(from);
 
     KMime::Headers::To* to = new KMime::Headers::To;
-    KCalCore::Person::List toList = data.event.emailAddressees();
+    const KCalendarCore::Person::List toList = data.event.emailAddressees();
     for (int i = 0, count = toList.count();  i < count;  ++i)
         to->addAddress(toList[i].email().toLatin1(), toList[i].name());
     message.setHeader(to);
@@ -342,7 +341,7 @@ void initHeaders(KMime::Message& message, KAMail::JobData& data)
     }
 
     KMime::Headers::Subject* subject = new KMime::Headers::Subject;
-    QString str = data.event.emailSubject();
+    const QString str = data.event.emailSubject();
     subject->fromUnicodeString(str, autoDetectCharset(str));
     message.setHeader(subject);
 
@@ -481,7 +480,7 @@ void KAMail::notifyQueued(const KAEvent& event)
     KMime::Types::Address addr;
     const QString localhost = QStringLiteral("localhost");
     const QString hostname  = QHostInfo::localHostName();
-    KCalCore::Person::List addresses = event.emailAddressees();
+    KCalendarCore::Person::List addresses = event.emailAddressees();
     for (int i = 0, end = addresses.count();  i < end;  ++i)
     {
         QByteArray email = addresses[i].email().toLocal8Bit();
@@ -513,7 +512,7 @@ QString KAMail::controlCentreAddress()
 * entered by the user.
 * Reply = the invalid item if error, else empty string.
 */
-QString KAMail::convertAddresses(const QString& items, KCalCore::Person::List& list)
+QString KAMail::convertAddresses(const QString& items, KCalendarCore::Person::List& list)
 {
     list.clear();
     QString invalidItem;
@@ -522,7 +521,7 @@ QString KAMail::convertAddresses(const QString& items, KCalCore::Person::List& l
         return invalidItem;
     for (int i = 0, count = mailboxes.count();  i < count;  ++i)
     {
-        KCalCore::Person person(mailboxes[i].name(), mailboxes[i].addrSpec().asString());
+        KCalendarCore::Person person(mailboxes[i].name(), mailboxes[i].addrSpec().asString());
         list += person;
     }
     return QString();
@@ -712,18 +711,10 @@ QStringList extractEmailsAndNormalize(const QString& emailAddresses)
 // Based on KMail KMMsgBase::autoDetectCharset().
 QByteArray autoDetectCharset(const QString& text)
 {
-    static QList<QByteArray> charsets;
-    if (charsets.isEmpty())
-        charsets << "us-ascii" << "iso-8859-1" << "locale" << "utf-8";
-
-    for (int i = 0, count = charsets.count();  i < count;  ++i)
+    for (QByteArray encoding : {"us-ascii", "iso-8859-1", "locale", "utf-8"})
     {
-        QByteArray encoding = charsets[i];
         if (encoding == "locale")
-        {
-            encoding = QTextCodec::codecForName(KLocale::global()->encoding())->name();
-            encoding = encoding.toLower();
-        }
+            encoding = QTextCodec::codecForLocale()->name().toLower();
         if (text.isEmpty())
             return encoding;
         if (encoding == "us-ascii")
@@ -733,7 +724,7 @@ QByteArray autoDetectCharset(const QString& text)
         }
         else
         {
-            const QTextCodec *codec = codecForName(encoding);
+            const QTextCodec* codec = codecForName(encoding);
             if (!codec)
                 qCDebug(KALARM_LOG) << "KAMail::autoDetectCharset: Something is wrong and I cannot get a codec. [" << encoding <<"]";
             else
