@@ -23,8 +23,8 @@
 
 #include "checkbox.h"
 
-#include <KCalCore/Duration>
-using namespace KCalCore;
+#include <KCalendarCore/Duration>
+using namespace KCalendarCore;
 
 #include <KLocalizedString>
 
