@@ -153,7 +153,7 @@ void Preferences::setNoAutoStart(bool yes)
     bool existingRO = true;   // whether the existing file is read-only
     QString autostartFile;
     const QStringList autostartDirs = QStandardPaths::standardLocations(QStandardPaths::GenericConfigLocation);
-    Q_FOREACH(const QString& dir, autostartDirs)
+    for (const QString& dir : autostartDirs)
     {
         const QString file = dir + QStringLiteral("/autostart/") + AUTOSTART_FILE;
         if (QFile::exists(file))
@@ -475,6 +475,7 @@ QString translateXTermPath(const QString& cmdline, bool write)
                 if (cmd[i] != quote)
                     continue;
                 // fall through to ' '
+                Q_FALLTHROUGH();
             case ' ':
                 params = cmd.mid(i);
                 cmd = cmd.left(i);
