@@ -28,8 +28,8 @@
 
 #include <kalarmcal/kadatetime.h>
 using namespace KAlarmCal;
-#include <KCalCore/Duration>
-using namespace KCalCore;
+#include <KCalendarCore/Duration>
+using namespace KCalendarCore;
 
 #include <KLocalizedString>
 
