@@ -59,11 +59,11 @@ SoundPicker::SoundPicker(QWidget* parent)
       mReadOnly(false)
 {
     QHBoxLayout* soundLayout = new QHBoxLayout(this);
-    soundLayout->setMargin(0);
+    soundLayout->setContentsMargins(0, 0, 0, 0);
     soundLayout->setSpacing(style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing));
     mTypeBox = new QWidget(this);    // this is to control the QWhatsThis text display area
     QHBoxLayout* typeBoxLayout = new QHBoxLayout(mTypeBox);
-    typeBoxLayout->setMargin(0);
+    typeBoxLayout->setContentsMargins(0, 0, 0, 0);
 
     QLabel* label = new QLabel(i18n_label_Sound(), mTypeBox);
     typeBoxLayout->addWidget(label);
